package com.bpcl.lpg.core.dao.impl;

import com.bpcl.core.model.SAPB2BUnitModel;
import com.bpcl.lpg.core.model.BDADeliveryChallanModel;
import java.util.List;
import de.hybris.platform.servicelayer.search.SearchResult;
import de.hybris.platform.servicelayer.exceptions.ModelNotFoundException;
import de.hybris.platform.servicelayer.exceptions.AmbiguousIdentifierException;
import java.util.Map;
import de.hybris.platform.servicelayer.search.FlexibleSearchQuery;
import java.util.HashMap;
import de.hybris.platform.servicelayer.util.ServicesUtil;
import com.bpcl.lpg.core.model.LpgDeliveryAssistantModel;
import javax.annotation.Resource;
import de.hybris.platform.servicelayer.search.FlexibleSearchService;
import com.bpcl.lpg.core.dao.LpgBDADao;

public class LpgBDADaoImpl implements LpgBDADao
{
    @Resource(name = "flexibleSearchService")
    private FlexibleSearchService flexibleSearchService;
    public static final String BDA_BY_MOBILE_NUMBER_QUERY = "SELECT {pk} FROM {LpgDeliveryAssistant} WHERE {uid}=?uid";
    public static final String BDA_DELIVERY_CHALLAN_QUERY = "SELECT {pk} FROM {BDADeliveryChallan} WHERE {deliveryChallanNo}=?deliveryChallanNo";
    public static final String DELIVERY_CHALLAN_BY_MOBILE_NO_QUERY = "SELECT {pk} FROM {BDADeliveryChallan} WHERE {deliveryAssistantMobileNo}=?deliveryAssistantMobileNo AND {status} = 'Pending'";
    public static final String SAPB2BUNIT_DISTRIBUTOR_NAME_QUERY = "SELECT {pk} FROM {SAPB2BUnit} WHERE {uid}=?uid";
    
    public LpgDeliveryAssistantModel getBDADetailsByUid(final String userId) {
        ServicesUtil.validateParameterNotNullStandardMessage("uid", (Object)userId);
        final Map<String, String> params = new HashMap<String, String>();
        params.put("uid", userId);
        final FlexibleSearchQuery searchQuery = new FlexibleSearchQuery("SELECT {pk} FROM {LpgDeliveryAssistant} WHERE {uid}=?uid");
        searchQuery.addQueryParameters((Map)params);
        final SearchResult<LpgDeliveryAssistantModel> searchResult = (SearchResult<LpgDeliveryAssistantModel>)this.flexibleSearchService.search(searchQuery);
        final List<LpgDeliveryAssistantModel> lpgBDAList = searchResult.getResult();
        if (lpgBDAList.size() > 1) {
            throw new AmbiguousIdentifierException("Found" + lpgBDAList.size() + "BDA with the MobileNumber value:mobileNowhich should be unique");
        }
        if (lpgBDAList.isEmpty()) {
            throw new ModelNotFoundException("No BDA with mobileNumber: " + userId + " found");
        }
        return lpgBDAList.get(0);
    }
    
    public BDADeliveryChallanModel getBdaDeliveryChallan(final String deliveryChallanNo) {
        final Map<String, String> params = new HashMap<String, String>(1);
        params.put("deliveryChallanNo", deliveryChallanNo);
        final FlexibleSearchQuery searchQuery = new FlexibleSearchQuery("SELECT {pk} FROM {BDADeliveryChallan} WHERE {deliveryChallanNo}=?deliveryChallanNo");
        searchQuery.addQueryParameters((Map)params);
        final SearchResult<BDADeliveryChallanModel> searchResult = (SearchResult<BDADeliveryChallanModel>)this.flexibleSearchService.search(searchQuery);
        return searchResult.getResult().isEmpty() ? null : searchResult.getResult().get(0);
    }
    
    public BDADeliveryChallanModel getBdaDeliveryChallanByMobileNo(final String mobileNumber) {
        final Map<String, String> params = new HashMap<String, String>(1);
        params.put("deliveryAssistantMobileNo", mobileNumber);
        final FlexibleSearchQuery searchQuery = new FlexibleSearchQuery("SELECT {pk} FROM {BDADeliveryChallan} WHERE {deliveryAssistantMobileNo}=?deliveryAssistantMobileNo AND {status} = 'Pending'");
        searchQuery.addQueryParameters((Map)params);
        final SearchResult<BDADeliveryChallanModel> searchResult = (SearchResult<BDADeliveryChallanModel>)this.flexibleSearchService.search(searchQuery);
        return searchResult.getResult().isEmpty() ? null : searchResult.getResult().get(0);
    }
    
    public SAPB2BUnitModel getDistributorNameByCode(final String distCode) {
        final Map<String, String> params = new HashMap<String, String>(1);
        params.put("uid", distCode);
        final FlexibleSearchQuery searchQuery = new FlexibleSearchQuery("SELECT {pk} FROM {SAPB2BUnit} WHERE {uid}=?uid");
        searchQuery.addQueryParameters((Map)params);
        final SearchResult<SAPB2BUnitModel> searchResult = (SearchResult<SAPB2BUnitModel>)this.flexibleSearchService.search(searchQuery);
        return searchResult.getResult().isEmpty() ? null : searchResult.getResult().get(0);
    }
}
